const { Field } = require('../../index');
let GlobalGroup = require('../includes/GlobalGroup');

let JustifyContent = require('../JustifyContent');
let Alignment = require('../Alignment');
let FlexDirection = require('../FlexDirection');

module.exports = class extends GlobalGroup {

	constructor() { 
		super()
		this.name('layout', 'Layout')
		this._build()
		return this
	}

	_build() {
		return this._buildChildrenArray(() => {
			(this._showAlignment ? this.appendChildren(this.#alignmentField()) : null);
			(this._showHorizontalAlignment ? this.appendChildren(this.#horizontalAlignmentField()) : null);
			(this._showVerticalAlignment ? this.appendChildren(this.#verticalAlignmentField()) : null);
			(this._showFlexDirection ? this.appendChildren(this.#flexDirectionField()) : null);
			(this._showContainerFull ? this.appendChildren(this.#containerFullField()) : null);
		})
	}
	
	// --- Show/Hide
	
	_showAlignment = true
	showAlignment(val = true) {
		this._showAlignment = !!val
		return this._build()
	}
	
	_showHorizontalAlignment = false
	showHorizontalAlignment(val = true) {
		this._showHorizontalAlignment = !!val
		return this._build()
	}
	
	_showVerticalAlignment = false
	showVerticalAlignment(val = true) {
		this._showVerticalAlignment = !!val
		return this._build()
	}
	
	_showFlexDirection = false
	showFlexDirection(val = true) {
		this._showFlexDirection = !!val
		return this._build()
	}

	_showContainerFull = true
	showContainerFull(val = true) {
		this._showContainerFull = !!val
		return this._build()
	}

	// --- Settings

	_applyToHAlignment = false
	applyToHAlignment(fn) { 
		this._showHorizontalAlignment = true
		this._applyToHAlignment = typeof fn =='function' ? fn : null
		return this._build()
	}
	
	_applyToVAlignment = false
	applyToVAlignment(fn) { 
		this._showVerticalAlignment = true
		this._applyToVAlignment = typeof fn =='function' ? fn : null
		return this._build()
	}

	_applyToAlignment = false
	applyToAlignment(fn) { 
		this._showAlignment = true
		this._applyToAlignment = typeof fn =='function' ? fn : null
		return this._build()
	}

	_defaultTextAlignment = 'default'
	defaultTextAlignment(val) {
		this._defaultTextAlignment = val.toString()
		return this._build()
	}

	_applyToFlexDirection = false
	applyToFlexDirection(fn) { 
		this._showFlexDirection = true
		this._applyToFlexDirection = typeof fn =='function' ? fn : null
		return this._build()
	}

	_applyToContainerFull = false
	applyToContainerFull(fn) { 
		this._showContainerFull = true
		this._applyToContainerFull = typeof fn =='function' ? fn : null
		return this._build()
	}

	// --- Fields

	#horizontalAlignmentField() { 
		return new JustifyContent()
			.name('horizontal_alignment', 'Horizontal Alignment')
			.applyIf(!!this._applyToHAlignment, field => this._applyToHAlignment(field))
	}

	#verticalAlignmentField() { 
		return new JustifyContent()
			.name('vertical_alignment', 'Veritcal Alignment')
			.applyIf(!!this._applyToVAlignment, field => this._applyToVAlignment(field))
	}

	#alignmentField() { 
		return new Alignment()
			.label('Text Alignment')
			.inlineHelpText('Align the content horizontally within the section.')
			.default(this._defaultTextAlignment || 'start')
			.applyIf(!!this._applyToAlignment, field => this._applyToAlignment(field))
	}
	
	#flexDirectionField() { 
		return new FlexDirection()
			.applyIf(!!this._applyToFlexDirection, field => this._applyToFlexDirection(field))
	}

	#containerFullField() {
		return Field
			.boolean()
			.name('container_full', 'ADVANCED: Stretch to screen width')
			.inlineHelpText('Make the module and its content, use the full screen width.')
			.set('display', 'toggle')
			.applyIf(!!this._applyToContainerFull, field => this._applyToContainerFull(field))
	}

}