const { Field } = require('../../index');
let GlobalGroup = require('../includes/GlobalGroup');

let SwiperJsSettings = require('./SwiperJsSettings');

module.exports = class extends GlobalGroup { 
	
	constructor() {
		super()
		this.name('logos', 'Logos')
		this._build()
		return this
	}

	_build() {
		return this._buildChildrenArray(() => { 
			this.appendChildren(this.#standardFields());
			this.appendChildren(new SwiperJsSettings());
			(this._showEnable ? this.prependChildren(this.#enableField()) : null);
		})
	}

	// --- Show/Hide

	_showEnable = true
	showEnable(val = true) {
		this._showEnable = !!val
		return this._build()
	}
	
	// --- Settings

	_minLogos = 0
	minLogos(val) {
		this._minLogos = parseInt(val) || 0
		return this._build()
	}
	
	_maxLogos = 6
	maxLogos(val) {
		this._maxLogos = parseInt(val) || null
		return this._build()
	}

	// --- Fields

	#standardFields() {
		return Field
			.image()
			.name('logos', 'Logo')
			.inlineHelpText('Select some logos to display')
			.set('resizable', false)
			.repeat({
				"min": this._minLogos,
				"max": this._maxLogos
			})
	}

	#enableField() {
		return Field
			.boolean()
			.name('show', 'Show Logos')
			.set('display', 'toggle')
			.default(true)
	}

}