let GlobalGroup = require('../includes/GlobalGroup');

let Padding = require('../Padding');

module.exports = class extends GlobalGroup {

	constructor() { 
		super()
		this.name('padding', 'Padding')
		this._build()
		return this
	}

	_build() {
		return this._buildChildrenArray(() => {
			(this._showTopPadding ? this.appendChildren(this.#topPaddingField()) : null);
			(this._showBottomPadding ? this.appendChildren(this.#bottomPaddingField()) : null);
		})
	}
	
	// --- Show/Hide
	
	_showTopPadding = true
	showTopPadding(val = true) {
		this._showTopPadding = !!val
		return this._build()
	}
	
	_showBottomPadding = true
	showBottomPadding(val = true) {
		this._showBottomPadding = !!val
		return this._build()
	}

	// --- Settings

	_defaultPadding = '5'
	defaultPadding(val) {
		this._defaultPadding = val.toString() || '0'
		return this._build()
	}
	
	_defaultTopPadding = null
	defaultTopPadding(val) {
		this._defaultTopPadding = val.toString() || '0'
		return this._build()
	}
	
	_defaultBottomPadding = null
	defaultBottomPadding(val) {
		this._defaultBottomPadding = val.toString() || '0'
		return this._build()
	}

	/**
	 * Usage:
	 * new Padding().filterChoices(c => (c[0] < 5))
	 */
	_filterChoices = false
	filterChoices(fn) { 
		this._filterChoices = typeof fn =='function' ? fn : null
		return this._build()
	}

	// --- Fields

	#topPaddingField() { 
		return this.baseField()
			.name('top', 'Content Padding Top')
			.default(this._defaultTopPadding != null ? this._defaultTopPadding : this._defaultPadding)
	}
	
	#bottomPaddingField() { 
		return this.baseField()
			.name('bottom', 'Content Padding Bottom')
			.default(this._defaultBottomPadding != null ? this._defaultBottomPadding : this._defaultPadding)
	}

	baseField() { 
		return new Padding()
			.applyIf(!!this._filterChoices, (field) => field.filterChoices(this._filterChoices))
			.default(this._defaultPadding)
	}

}