let GlobalGroup = require('../includes/GlobalGroup');

let Theme = require('./Theme');
let Layout = require('./Layout');
let Padding = require('./Padding');

module.exports = class extends GlobalGroup {

	constructor() { 
		super()
		this.name('style', 'Style')
		this._build()
		return this
	}

	_build() {
		return this._buildChildrenArray(() => {
			(this._showTheme ? this.appendChildren(this.#themeGroup()) : null);
			(this._showLayout ? this.appendChildren(this.#layoutGroup()) : null);
			(this._showPadding ? this.appendChildren(this.#paddingGroup()) : null);
		})
	}
	
	// --- Show/Hide

	_showTheme = true
	showTheme(val = true) {
		this._showTheme = !!val
		return this._build()
	}

	_showLayout = true
	showLayout(val = true) {
		this._showLayout = !!val
		return this._build()
	}

	_showPadding = true
	showPadding(val = true) {
		this._showPadding = !!val
		return this._build()
	}
	
	// --- Settings

	_applyToTheme = false
	applyToTheme(fn) { 
		this._applyToTheme = typeof fn =='function' ? fn : null
		return this._build()
	}

	_applyToLayout = false
	applyToLayout(fn) { 
		this._applyToLayout = typeof fn =='function' ? fn : null
		return this._build()
	}

	_applyToPadding = false
	applyToPadding(fn) { 
		this._applyToPadding = typeof fn =='function' ? fn : null
		return this._build()
	}

	// --- Fields

	#themeGroup() {
		return new Theme()
			.applyIf(!!this._applyToTheme, field => this._applyToTheme(field))
	}
	
	#layoutGroup() {
		return new Layout()
			.applyIf(!!this._applyToLayout, field => this._applyToLayout(field))
	}

	#paddingGroup() {
		return new Padding()
			.applyIf(!!this._applyToPadding, field => this._applyToPadding(field))
	}

}