const { Field } = require('../../index');
let GlobalGroup = require('../includes/GlobalGroup');

let Heading = require('../Heading');
let BasicText = require('../BasicText');

module.exports = class extends GlobalGroup {

	constructor() { 
		super();
		this.name("testimonials", "testimonials")
		this._build()
		return this
	}

	_build() {
		return this._buildChildrenArray(() => { 
			this.appendChildren(this.#standardFields());
			(this._showRole ? this.appendChildren(this.#roleField()) : null);
			(this._showCompany ? this.appendChildren(this.#companyField()) : null);
			(this._showImage ? this.appendChildren(this.#imageField()) : null);
			(this._showEnable ? this.prependChildren(this.#enableField()) : null);
		})
	}

	// --- Show/Hide

	_showEnable = true
	showEnable(val = true) {
		this._showEnable = !!val
		return this._build()
	}

	_showRole = false
	showRole(val = true) {
		this._showRole = !!val
		return this._build()
	}

	_showCompany = true
	showCompany(val = true) {
		this._showCompany = !!val
		return this._build()
	}

	_showImage = true
	showImage(val = true) {
		this._showImage = !!val
		return this._build()
	}

	// --- Settings

	_defaultName = 'John Smith'
	defaultName(val) {
		this._defaultName = val.toString()
		return this._build()
	}

	_defaultRole = 'CEO'
	defaultRole(val) {
		this._defaultRole = val.toString()
		return this._build()
	}

	_defaultCompany = 'ABC Company'
	defaultCompany(val) {
		this._defaultCompany = val.toString()
		return this._build()
	}

	// --- Fields

	#enableField() {
		return Field
			.boolean()
			.name('visible', 'Enable this Item')
			.set('display', 'toggle')
			.default(true)
	}

	#standardFields() {
		return [
			new Heading()
				.name('customer', 'Name')
				.default(this._defaultName),
			
			new BasicText()
				.name('text', 'Quote/Text')
				.default('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quam vulputate dignissim suspendisse in est. Viverra mauris in aliquam sem fringilla. Odio facilisis mauris sit amet. Amet est placerat in egestas. Dictumst quisque sagittis purus sit amet. Vel fringilla est ullamcorper eget nulla facilisi etiam dignissim.')
	
		]
	}

	#roleField() {
		return new Heading()
			.name('title', 'Title/Role')
			.default(this._defaultRole)
	}

	#companyField() {
		return new Heading()
			.name('company', 'Company')
			.default(this._defaultCompany)
	}

	#imageField() {
		return Field
			.image()
			.name('image', 'Image')
			.inlineHelpText('Select an image to display')
			.set('resizable', false)
	}

}