import { injectScripts, checkAllObjectValuesAreTrue } from "../../scriptInjector"

let hasBeenLoaded = false

/**
 * Loads VueMask Library from CDN
 * 
 * Usage:
	import VueMaskLoader from 'hs-dev-helper/js-toolkit/cdnLoaders/VueMask/VueMaskLoader'
	(async () => await VueMaskLoader.loadVueMaskScripts())()
 */
export const loader = class {

	vueMask = {
		ready : false,
		loaded: {
			script: false
		}
	}

	loadVueMaskScripts = (onload = null) => { 
		return new Promise((res, rej) => { 

			const checkIfAllAreLoaded = () => {
				this.vueMask.ready = checkAllObjectValuesAreTrue(this.vueMask.loaded)
				if (this.vueMask.ready) {
					let payload = {VueMask: window.VueTheMask}
					// Fire Event
					var event = new CustomEvent('VueMaskLoaded', { detail : payload });
					window.dispatchEvent(event);
					// OnLoad Callback
					if (this.vueMask.loaded.script && !!onload && typeof onload == 'function') { 
						onload(payload)
					}
					// Flag
					hasBeenLoaded = true
					// Return Promise
					res(payload)
				}
			}
			
			let scripts = [
				{
					//https://vuejs-tips.github.io/vue-the-mask/
					type: 'script',
					src: '//cdnjs.cloudflare.com/ajax/libs/vue-the-mask/0.11.1/vue-the-mask.min.js',
					precheck: () => (!!window.Vue && typeof window.Vue == 'function'),
					onload: () => {
						this.vueMask.loaded.script = (typeof window.VueTheMask == 'object')
						window.Vue.use(window.VueTheMask);
						checkIfAllAreLoaded()
					}
				}
			]
			if (!hasBeenLoaded) {
				injectScripts(scripts)
			}
		})
	}


}


/**
 * Load VueMask from Vue
 * 
 * Usage
	import { VueMaskMixin } from 'hs-dev-helper/js-toolkit/cdnLoaders/VueMask/VueMaskLoader';
	...
	mixins: [VueMaskMixin],
	...
	computed: {
		ready() { 
			return !!this.vueMask.ready
		},
		...
	}
*/
export const VueMaskMixin = {
	created() {
		window.addEventListener('VueMaskLoaded', () => {
			this.vueMask.ready = true
		});
	},
	beforeMount() {
		(async () => await (new loader).loadVueMaskScripts())()
	},
	data: () => ({
		vueMask : {ready: false}
	}),
}

export default new loader