import { injectScripts, checkAllObjectValuesAreTrue } from "../../scriptInjector"

let hasBeenLoaded = false

/**
 * Loads Vue Multiselect Library from CDN
 * 
 * Usage:
	import VueMultiselectLoader from 'hs-dev-helper/js-toolkit/cdnLoaders/VueMultiselect/VueMultiselectLoader'
	(async () => await VueMultiselectLoader.loadVueMultiselectScripts())()
 */
export const loader = class {

	vueMultiselect = {
		ready : false,
		loaded: {
			script: false,
			style: false
		}
	}

	loadVueMultiselectScripts = (onload = null) => { 
		return new Promise((res, rej) => { 

			const checkIfAllAreLoaded = () => {
				this.vueMultiselect.ready = checkAllObjectValuesAreTrue(this.vueMultiselect.loaded)
				if (this.vueMultiselect.ready) {
					let payload = {VueMultiselect: window.VueMultiselect}
					// Fire Event
					var event = new CustomEvent('VueMultiselectLoaded', { detail : payload });
					window.dispatchEvent(event);
					// OnLoad Callback
					if (this.vueMultiselect.loaded.script && !!onload && typeof onload == 'function') { 
						onload(payload)
					}
					// Flag
					hasBeenLoaded = true
					// Return Promise
					res(payload)
				}
			}
			
			let scripts = [
				{
					type: 'script',
					src: '//cdnjs.cloudflare.com/ajax/libs/vue-multiselect/2.1.6/vue-multiselect.min.js',
					precheck: () => (!!window.Vue && typeof window.Vue == 'function'),
					onload: () => {
						this.vueMultiselect.loaded.script = (typeof window.VueMultiselect == 'object')
						window.Vue.component('multiselect', window.VueMultiselect.default)
						checkIfAllAreLoaded()
					}
				},
				{
					type: 'style',
					src: '//cdnjs.cloudflare.com/ajax/libs/vue-multiselect/2.1.6/vue-multiselect.min.css',
					onload: () => {
						this.vueMultiselect.loaded.style = true
						checkIfAllAreLoaded()
					}
				}
			]
			if (!hasBeenLoaded) {
				injectScripts(scripts)
			}
		})
	}


}


/**
 * Load Multiselect from Vue
 * 
 * Usage
	import { VueMultiselectMixin } from 'hs-dev-helper/js-toolkit/cdnLoaders/VueMultiselect/VueMultiselectLoader';
	...
	mixins: [VueMultiselectMixin],
	...
	computed: {
		ready() { 
			return !!this.vueMultiselect.ready
		},
		...
	}
*/
export const VueMultiselectMixin = {
	created() {
		window.addEventListener('VueMultiselectLoaded', () => {
			this.vueMultiselect.ready = true
		});
	},
	beforeMount() {
		(async () => await (new loader).loadVueMultiselectScripts())()
	},
	data: () => ({
		vueMultiselect : {ready: false}
	}),
}

export default new loader