import { injectScripts, checkAllObjectValuesAreTrue } from "../../scriptInjector"

let hasBeenLoaded = false

/**
 * Loads Lodash Library from CDN
 * 
 * Usage:
	import lodashLoader from 'hs-dev-helper/js-toolkit/cdnLoaders/lodash/lodashLoader'
	(async () => await lodashLoader.loadLodashScripts())()
 */
export const loader = class {

	lodash = {
		ready : false,
		loaded: {
			script: false
		}
	}

	loadLodashScripts = (onload = null) => { 
		return new Promise((res, rej) => { 
			const checkIfAllAreLoaded = () => {
				this.lodash.ready = checkAllObjectValuesAreTrue(this.lodash.loaded)
				if (this.lodash.ready) {
					let payload = { loadash: window._ }
					// Fire Event
					var event = new CustomEvent('LodashLoaded', { detail : payload });
					window.dispatchEvent(event);
					// Onload Callback
					if (this.lodash.loaded.script && !!onload && typeof onload == 'function') { 
						onload(window.lodash)
					}
					// Flag
					hasBeenLoaded = true
					// Return Promise
					res(payload)
				}
			}	
			
			let scripts = [
				{
					type: 'script',
					src: 'https://cdn.jsdelivr.net/npm/lodash@4.17.21/lodash.min.js',
					onload: () => {
						this.lodash.loaded.script = (typeof window._ == 'function')
						checkIfAllAreLoaded()
					}
				}
			]
			if (!hasBeenLoaded) {
				injectScripts(scripts)
			}
		})
	}

}

export default new loader