const cleanCopy = (source) => { 
	return JSON.parse(JSON.stringify(source));
}

const getWithDot = (obj, selector) => {
	if (typeof selector === 'string' || selector instanceof String) {
		let selectorPath = selector.split('.');
		let first = [...selectorPath].shift();
		if (obj[first]) {
			return selectorPath.reduce((o, k) => o[k], obj);
		}
	}
	return null;
}

const setWithDot = (object, path, value) => {
	var way = path.replace(/\[/g, '.').replace(/\]/g, '').split('.'),
		last = way.pop();

	way.reduce(function (o, k, i, kk) {
		return o[k] = o[k] || (isFinite(i + 1 in kk ? kk[i + 1] : last) ? [] : {});
	}, object)[last] = value;
	
	return value
}

const sortItems = (arr, key, asc = false) => {
	return arr.sort((a, b) => (a[key] > b[key]) ? (asc ? 1 : -1) : ((b[key] > a[key]) ? (asc ? -1 : 1) : 0));
}

const filterItemsByQuery =  (items, query, searchableTerms) => {
	if (query && typeof query === 'string') {
		return items.filter((item) => {
			return query.toLowerCase().split(' ').every(v => {
				var res = false;
				searchableTerms.forEach(t => {
					let searchable = getWithDot(item, t);
					if (searchable) {
						res = (!res && searchable.toLowerCase().includes(v)) ? true : res;
					}
				});
				return res;
			})
		})
	} else {
		return items;
	}
}

const objToFormData =  (object) => {
	let data = new FormData();
	Object.entries(object).forEach(d => {
		var [key, value] = d;
		if(typeof value === "boolean") {value = value ? 1 : 0;}
		if (value != null) {
			data.set(key, value);
		}
	});
	return data;
}

const deepFind =  (items, key, value, childrenKey) => {
	var found = false
	items.find(i => {
		if (i[key] == value) {
			found = i
			return true;
		}
		else if(!!i[childrenKey]) {
			found = deepFind(i[childrenKey], key, value, childrenKey)
		}
	});
	return found;
}

const deepExtend = (targetObject,...args) => {
	targetObject = targetObject || {};
	args = args.filter(o => (typeof o == 'object' && !Array.isArray(o)))
	
	for (let i = 0; i < args.length; i++) {
		const object = args[i] || {};
		for (const key in object) {
			if (Object.prototype.hasOwnProperty.call(object, key)) {
				if (typeof object[key] === "object") {
					if (object[key] instanceof Array) {
						targetObject[key] = object[key].slice(0);
					} else {
						targetObject[key] = deepExtend(
							targetObject[key],
							object[key]
						);
					}
				} else {
					targetObject[key] = object[key];
				}
			}
		}
	}

	return targetObject;
}

exports.cleanCopy = cleanCopy
exports.getWithDot = getWithDot
exports.setWithDot = setWithDot
exports.sortItems = sortItems
exports.filterItemsByQuery = filterItemsByQuery
exports.objToFormData = objToFormData
exports.deepFind = deepFind
exports.deepExtend = deepExtend

module.exports = {
	cleanCopy,
	getWithDot,
	setWithDot,
	sortItems,
	filterItemsByQuery,
	objToFormData,
	deepFind,
	deepExtend
}