const setupHubspotData = (data) => {
	return deepExtend({
		"submittedAt": Date.now(),
		"fields": [],
		"context": {
			"pageUri": window.location.href,
			"pageName": document.title || ""
		},
		"legalConsentOptions": {
			"consent": {
				"consentToProcess": true,
				"text": "I agree",
				"communications": [
					{
						"value": true,
						"subscriptionTypeId": 0,
						"text": ""
					}
				]
			}
		}
	},data)
}

const send =  (obj = {}) => {
	obj = Object.assign({},{
		url : '',
		method : 'GET',
		params: {},
		body : ''
	},obj)
	let { url , method, headers, params, body } = obj
	
	if (!url) { throw 'No url set' }
	url = new URL(url);
	url.search = new URLSearchParams(params);

	return new Promise((resolve, reject) => {
		let xhr = new XMLHttpRequest();
		xhr.open(method, url.toString());
		// Set Request Header
		xhr.setRequestHeader("Accept", "application/json");
		xhr.setRequestHeader("Content-Type", "application/json");
		// Response
		xhr.onload = () => {
			let success = (xhr.status >= 200 && xhr.status < 300);
			
			// Set Body
			let body = {}
			try {
				body = JSON.parse(xhr.response)
			} catch { }

			//
			let res = {
				success,
				status: xhr.status,
				statusText: xhr.statusText,
				body
			};
			// Resolve
			(success ? resolve(res) : reject(res));
		};
		xhr.onerror = (e) => {
			reject({
				success : false,
				status: 500,
				statusText: "** An error occurred during the submission",
				body: {}
			})
		};
		// Send
		xhr.send( JSON.stringify(body));
	});
}

const sleep = (ms) => {
	return new Promise(resolve => setTimeout(resolve, ms));
}

exports.setupHubspotData = setupHubspotData
exports.send = send
exports.sleep = sleep

module.exports = {
	setupHubspotData,
	send,
	sleep
}